----------------------------------- 
-- Bookbiz database creating script  
-----------------------------------

-- 1. Drop old tables

@@bDrop

-- 2. Create tables

----------------------
--    --
----------------------
CREATE TABLE Titles
( 
	Title_Id CHAR( 6 ) PRIMARY KEY,         		--  
	Title VARCHAR2( 80 ) NOT NULL,          		--  
	TType CHAR( 12 ),                       		--  
	Pub_Id CHAR( 4 ),                       		--    
	Price NUMBER( 6, 2 ),                   		-- 
	Advance NUMBER,						-- ( (                           
	Ytd_Sales NUMBER(7),					--   
	Contract NUMBER( 1 )					--    
                 CHECK( Contract IN( 0,1 ) ) 
                 NOT NULL,
	Notes VARCHAR2( 200 ),                  		-- 
	Pubdate DATE                            		--   
);

COMMENT ON TABLE Titles IS 'Table of books.';
COMMENT ON COLUMN Titles.Title_id IS 'Book unique identifier.';
COMMENT ON COLUMN Titles.Title IS 'Book name.';
COMMENT ON COLUMN Titles.TType IS 'Kind of book.';
COMMENT ON COLUMN Titles.Pub_Id IS 'Publisher identifier for the book.';
COMMENT ON COLUMN Titles.Price IS 'Book price in USD.';
COMMENT ON COLUMN Titles.Advance IS 'Expense of the book publishing.';
COMMENT ON COLUMN Titles.Ytd_Sales IS 'Number of sales of the book.';
COMMENT ON COLUMN Titles.Contract IS 'Is contract of the book signed ?';
COMMENT ON COLUMN Titles.Notes IS 'Free notes.';
COMMENT ON COLUMN Titles.Pubdate IS 'Date of publication.';

-----------------------
--    --
-----------------------
CREATE TABLE Authors
( 
	Au_Id CHAR( 11 ) PRIMARY KEY,				--  
	Au_LName VARCHAR2( 40 ) NOT NULL,			--    
	Au_FName VARCHAR2( 20 ),				--    
	Phone CHAR( 12 ) NOT NULL,				-- '   
	Address VARCHAR2( 40 ),					--  
	City VARCHAR2( 20 ),					--  
	State CHAR( 2 ),					--  
	Zip CHAR( 5 )						-- Zip code
);

COMMENT ON TABLE Authors IS 'Table of authors.';
COMMENT ON COLUMN Authors.Au_Id IS 'Author''s unique identifier.';
COMMENT ON COLUMN Authors.Au_LName IS 'Author''s last name. May not be NULL';
COMMENT ON COLUMN Authors.Au_FName IS 'Author''s first name.';
COMMENT ON COLUMN Authors.Phone IS 'Author''s phone number. May not be NULL';
COMMENT ON COLUMN Authors.Address IS 'Author''s address.';
COMMENT ON COLUMN Authors.City IS 'Author''s city name.';
COMMENT ON COLUMN Authors.State IS 'Two letter abbreviation of state.';
COMMENT ON COLUMN Authors.Zip IS '5 letter zip code.';

-----------------------------
--     --
-----------------------------
CREATE TABLE Publishers
( 
	Pub_Id CHAR( 4 ) PRIMARY KEY,				--    
	Pub_name VARCHAR2( 40 ),				--   
	Address VARCHAR2( 40 ),					--   
	City VARCHAR2( 20 ),					--  
	State CHAR( 2 )						--  
);

COMMENT ON TABLE Publishers IS 'Table of publishers.';
COMMENT ON COLUMN Publishers.Pub_Id IS 'Publisher''s unique identifier.';
COMMENT ON COLUMN Publishers.Pub_Name IS 'Publisher''s name.';
COMMENT ON COLUMN Publishers.Address IS 'Publisher''s address.';
COMMENT ON COLUMN Publishers.City IS 'Publisher''s city name.';
COMMENT ON COLUMN Publishers.State IS 'Two letter abbreviation of state.';

-----------------------------
--    --
-----------------------------
CREATE TABLE Editors
( 
	Ed_Id CHAR( 11 ) PRIMARY KEY,				--  
	Ed_LName VARCHAR2( 40 ) NOT NULL,			--    
	Ed_FName VARCHAR2( 20 ) NOT NULL,			--    
	Ed_Pos VARCHAR2( 12 ),					-- '   
	Phone CHAR( 12 ),					-- '   
	Address VARCHAR2( 40 ),					--   
	City VARCHAR2( 20 ),					--  
	State CHAR( 2 ),					--  	
	Zip CHAR( 5 )						-- Zip code
);

COMMENT ON TABLE Editors IS 'Editor''s unique idntifier.';
COMMENT ON COLUMN Editors.Ed_Id IS 'Editor''s unique idntifier.';
COMMENT ON COLUMN Editors.Ed_LName IS 'Editor''s last name.';
COMMENT ON COLUMN Editors.Ed_FName IS 'Editor''s first name.';
COMMENT ON COLUMN Editors.Ed_Pos IS 'Editor''s position.';
COMMENT ON COLUMN Editors.Phone IS 'Editor''s phone number.';
COMMENT ON COLUMN Editors.Address IS 'Editor''s address.';
COMMENT ON COLUMN Editors.City IS 'Editor''s city name.';
COMMENT ON COLUMN Editors.State IS 'Two letter abbreviation of state.';
COMMENT ON COLUMN Editors.Zip IS '5 letter zip code.';

-----------------------------
--    --
-----------------------------
CREATE TABLE RoySched
( 
	Title_Id CHAR( 6 ) NOT NULL 
                           REFERENCES Titles( Title_Id ),	--  
	LoRange NUMBER( 6 ),					-- (   ( 
	HiRange NUMBER( 6 ),					-- (   ( 
	Royalty NUMBER( 3, 2 )					-- (0,1)    
);

COMMENT ON TABLE RoySched IS 'Table for royalty calculation.';
COMMENT ON COLUMN RoySched.Title_Id IS 'Book identifier. May be written in several records';
COMMENT ON COLUMN RoySched.LoRange IS 'Minimal value of sales';
COMMENT ON COLUMN RoySched.HiRange IS 'Maximal value of sales';
COMMENT ON COLUMN RoySched.Royalty IS 'Part of royalty in total receipt of sales';

-----------------------------------
--          - --
--  -     --
-----------------------------------
CREATE TABLE TitleAuthors
( 
	Au_Id CHAR( 11 ) NOT NULL REFERENCES Authors( Au_Id ),  --  
	Title_Id CHAR( 6 ) NOT NULL 
                           REFERENCES Titles( Title_Id ),	--  
	Au_Ord NUMBER( 2 ),					--        
	RoyaltyShare NUMBER( 3, 2 ),				-- (0,1]     
	PRIMARY KEY ( Au_Id, Title_Id )
);

COMMENT ON TABLE TitleAuthors IS 'Connection table between Titles and Authors.';
COMMENT ON COLUMN TitleAuthors.Au_Id IS 'Author''s identifier.';
COMMENT ON COLUMN TitleAuthors.Title_Id IS 'Book identifier.';
COMMENT ON COLUMN TitleAuthors.Au_Ord IS 'Ordinal number of the author in the book title.';
COMMENT ON COLUMN TitleAuthors.RoyaltyShare IS 'Part of the author in the book royalty. Must be > 0 and <= 1';

-----------------------------------
--          - --
--  -     --
-----------------------------------
CREATE TABLE TitlEditors
( 
	Ed_Id CHAR( 11 ) NOT NULL 
                         REFERENCES Editors( Ed_Id ),		--  
	Title_Id CHAR( 6 ) NOT NULL 
                           REFERENCES Titles( Title_Id ),	--  
	Ed_Ord NUMBER(1),					--        
        PRIMARY KEY ( Ed_Id, Title_Id )
);

COMMENT ON TABLE TitlEditors IS 'Connection table between Titles and Editors.';
COMMENT ON COLUMN TitlEditors.Ed_Id IS 'Editor''s identifier.';
COMMENT ON COLUMN TitlEditors.Title_Id IS 'Book identifier.';
COMMENT ON COLUMN TitlEditors.Ed_Ord IS 'Ordinal number of the editor in the book title.';

------------------
--   --
------------------
CREATE TABLE TitlSales
( 
	SoNum NUMBER( 6 ) PRIMARY KEY,				--  
	Stor_Id CHAR( 4 ) NOT NULL,				--  
	PoNum VARCHAR2( 20 ) NOT NULL,                          --   
	SDate DATE						--  
);

COMMENT ON TABLE TitlSales IS 'Table of book orders.';
COMMENT ON COLUMN TitlSales.SoNum IS 'Number of the order.';
COMMENT ON COLUMN TitlSales.Stor_Id IS 'Store identifier.';
COMMENT ON COLUMN TitlSales.PoNum IS 'Store reference';
COMMENT ON COLUMN TitlSales.SDate IS 'Date of the order.';

-----------------------
--    --
-----------------------
CREATE TABLE TitlSalesDet
( 
	SoNum NUMBER( 6 ) NOT NULL 
                          REFERENCES TitlSales( SoNum ),	--  
	Title_Id CHAR( 6 ) NOT NULL 
                           REFERENCES Titles( Title_Id ),	--  
	Qty_Ordered NUMBER( 3 ) NOT NULL,			--  
	Qty_Shipped NUMBER( 3 ) NULL,				--  
	Date_Shipped DATE					--  
);

COMMENT ON TABLE TitlSalesDet IS 'Table of details of book orders.';
COMMENT ON COLUMN TitlSalesDet.SoNum IS 'Number of the order.';
COMMENT ON COLUMN TitlSalesDet.Title_Id IS 'Book identifier.';
COMMENT ON COLUMN TitlSalesDet.Qty_Ordered IS 'Ordered quantity of the book.';
COMMENT ON COLUMN TitlSalesDet.Qty_Shipped IS 'Shipped quantity of the book.';
COMMENT ON COLUMN TitlSalesDet.Date_Shipped IS 'Date of shipping.';

--------------------
--   ---
--------------------
CREATE INDEX TitleNm_Ind ON Titles ( Title );
CREATE INDEX AuNm_Ind ON Authors ( Au_LName, Au_FName );
CREATE INDEX EdNm_Ind ON Editors ( Ed_LName, Ed_FName ) ;
CREATE INDEX Rstid_Ind ON Roysched ( Title_Id );
CREATE INDEX TitlSalesDet_Ind ON TitlSalesDet ( SoNum );

@@bInsert