/*
******************** 
** Bookbiz script ** 
********************
*/

DROP TABLE Authors;
CREATE TABLE Authors
( 
	au_id CHAR( 11 ) NOT NULL,
	au_lname VARCHAR2( 40 ) NOT NULL,
	au_fname VARCHAR2( 20 ) NOT NULL,
	phone CHAR( 12 ) NULL,
	address VARCHAR2( 40 ) NULL,
	city VARCHAR2( 20 ) NULL,
	state CHAR( 2 ) NULL,
	zip CHAR( 5 ) NULL
 );
GRANT SELECT ON Authors TO PUBLIC;

DROP TABLE Publishers;
CREATE TABLE Publishers
( 
	pub_id CHAR( 4 ) NOT NULL,
	pub_name VARCHAR2( 40 ) NULL,
	address VARCHAR2( 40 ) NULL,
	city VARCHAR2( 20 ) NULL,
	state CHAR( 2 ) NULL
 );
GRANT SELECT ON Publishers to PUBLIC;

DROP TABLE Roysched;
CREATE TABLE Roysched
( 
	title_id CHAR( 6 ) NOT NULL,
	lorange NUMBER( 6 ) NULL,
	hirange NUMBER( 6 ) NULL,
	royalty NUMBER( 3, 2 ) NULL
 );
GRANT SELECT ON Roysched TO PUBLIC;

DROP TABLE TitleAuthors;
CREATE TABLE TitleAuthors
( 
	au_id CHAR( 11 ) NOT NULL,
	title_id CHAR( 6 ) NOT NULL,
	au_ord NUMBER( 2 ) NULL,
	royaltyshare NUMBER( 3, 2 ) NULL
 );
GRANT SELECT ON TitleAuthors TO PUBLIC;

DROP TABLE Titles;
CREATE TABLE Titles
( 
	title_id CHAR( 6 ) NOT NULL,
	title VARCHAR2( 80 ) NOT NULL,
	ttype CHAR( 12 ) NULL,
	pub_id CHAR( 4 ) NULL,
	price NUMBER( 6, 2 ) NULL,
	advance NUMBER NULL,
	ytd_sales NUMBER(7) NULL,
	contract NUMBER( 1 ) CHECK(  contract IN(  0,1  )  ) NOT NULL,
	notes VARCHAR2( 200 ) NULL,
	pubdate DATE NULL
 );
GRANT SELECT ON Titles TO PUBLIC;

DROP TABLE Editors;
CREATE TABLE Editors
( 
	ed_id CHAR( 11 ) NOT NULL,
	ed_lname VARCHAR2( 40 ) NOT NULL,
	ed_fname VARCHAR2( 20 ) NOT NULL,
	ed_pos VARCHAR2( 12 ) NULL,
	phone CHAR( 12 ) NULL,
	address VARCHAR2( 40 ) NULL,
	city VARCHAR2( 20 ) NULL,
	state CHAR( 2 ) NULL,
	zip CHAR( 5 ) NULL
 );
GRANT SELECT ON Editors TO PUBLIC;

DROP TABLE TitlEditors;
CREATE TABLE TitlEditors
( 
	ed_id CHAR( 11 ) NOT NULL,
	title_id CHAR( 6 ) NOT NULL,
	ed_ord NUMBER(1) NULL
 );
GRANT SELECT ON TitlEditors TO PUBLIC;

DROP TABLE Sales;
CREATE TABLE Sales
( 
	sonum NUMBER( 6 ) NOT NULL,
	stor_id CHAR( 4 ) NOT NULL,
	ponum VARCHAR2( 20 ) NOT NULL,
	sdate DATE NULL
 );
GRANT SELECT ON Sales TO PUBLIC;

DROP TABLE SalesDetails;
CREATE TABLE SalesDetails
( 
	sonum NUMBER( 6 ) NOT NULL,
	qty_ordered NUMBER( 3 ) NOT NULL,
	qty_shipped NUMBER( 3 ) NULL,
	title_id CHAR( 6 ) NOT NULL,
	date_shipped DATE NULL
 );
GRANT SELECT ON SalesDetails TO PUBLIC;

CREATE UNIQUE INDEX PubInd ON Publishers ( pub_id );
CREATE UNIQUE INDEX AuidInd ON Authors ( au_id );
CREATE INDEX AunmInd ON Authors ( au_lname, au_fname );
CREATE UNIQUE INDEX TitleidInd ON Titles ( title_id );
CREATE INDEX TitleInd ON Titles ( title );
CREATE UNIQUE INDEX TaInd ON TitleAuthors ( au_id, title_id );
CREATE UNIQUE INDEX EdInd ON Editors ( ed_id );
CREATE INDEX EdnmInd ON Editors ( ed_lname, ed_fname ) ;
CREATE UNIQUE INDEX TeInd ON TitlEditors ( ed_id, title_id ); 
CREATE INDEX RstidInd ON Roysched ( title_id );
CREATE UNIQUE INDEX SalesInd ON Sales ( sonum );
CREATE INDEX SalesDetInd ON SalesDetails ( sonum );

INSERT INTO Authors VALUES( '409-56-7008', 'Bennet', 'Abraham', '415 658-9932', '6223 Bateman St.', 'Berkeley', 'CA', '94705' );
INSERT INTO Authors VALUES ( '213-46-8915', 'Green', 'Marjorie', '415 986-7020', '309 63rd St. #411', 'Oakland', 'CA', '94618' );
INSERT INTO Authors VALUES( '238-95-7766', 'Carson', 'Cheryl', '415 548-7723', '589 Darwin Ln.', 'Berkeley', 'CA', '94705' );
INSERT INTO Authors VALUES( '998-72-3567', 'Ringer', 'Albert', '801 826-0752', '67 Seventh Av.', 'Salt Lake City', 'UT', '84152' );
INSERT INTO Authors VALUES( '899-46-2035', 'Ringer', 'Anne', '801 826-0752', '67 Seventh Av.', 'Salt Lake City', 'UT', '84152' );
INSERT INTO Authors VALUES( '722-51-5454', 'DeFrance', 'Michel', '219 547-9982', '3 Balding Pl.', 'Gary', 'IN', '46403' );
INSERT INTO Authors VALUES( '807-91-6654', 'Panteley', 'Sylvia', '301 946-8853', '1956 Arlington Pl.', 'Rockville', 'MD', '20853' );
INSERT INTO Authors VALUES( '893-72-1158', 'McBadden', 'Heather', '707 448-4982', '301 Putnam', 'Vacaville', 'CA', '95688' );
INSERT INTO Authors VALUES( '724-08-9931', 'Stringer', 'Dirk', '415 843-2991', '5420 Telegraph Av.', 'Oakland', 'CA', '94609' );
INSERT INTO Authors VALUES( '274-80-9391', 'Straight', 'Dick', '415 834-2919', '5420 College Av.', 'Oakland', 'CA', '94609' );
INSERT INTO Authors VALUES( '756-30-7391', 'Karsen', 'Livia', '415 534-9219', '5720 McAuley St.', 'Oakland', 'CA', '94609' );
INSERT INTO Authors VALUES( '724-80-9391', 'MacFeather', 'Stearns', '415 354-7128', '44 Upland Hts.', 'Oakland', 'CA', '94612' );
INSERT INTO Authors VALUES( '427-17-2319', 'Dull', 'Ann', '415 836-7128', '3410 Blonde St.', 'Palo Alto', 'CA', '94301' );
INSERT INTO Authors VALUES( '672-71-3249', 'Yokomoto', 'Akiko', '415 935-4228', '3 Silver Ct.', 'Walnut Creek', 'CA', '94595' );
INSERT INTO Authors VALUES( '267-41-2394', 'O''Leary', 'Michael', '408 286-2428', '22 Cleveland Av. #14', 'San Jose', 'CA', '95128' );
INSERT INTO Authors VALUES( '472-27-2349', 'Gringlesby', 'Burt', '707 938-6445', 'PO Box 792', 'Covelo', 'CA', '95428' );
INSERT INTO Authors VALUES( '527-72-3246', 'Greene', 'Morningstar', '615 297-2723', '22 Graybar House Rd.', 'Nashville', 'TN', '37215' );
INSERT INTO Authors VALUES( '172-32-1176', 'White', 'Johnson', '408 496-7223', '10932 Bigge Rd.', 'Menlo Park', 'CA', '94025' );
INSERT INTO Authors VALUES( '712-45-1867', 'del Castillo', 'Innes', '615 996-8275', '2286 Cram Pl. #86', 'Ann Arbor', 'MI', '48105' );
INSERT INTO Authors VALUES( '846-92-7186', 'Hunter', 'Sheryl', '415 836-7128', '3410 Blonde St.', 'Palo Alto', 'CA', '94301' );
INSERT INTO Authors VALUES( '486-29-1786', 'Locksley', 'Chastity', '415 585-4620', '18 Broadway Av.', 'San Francisco', 'CA', '94130' );
INSERT INTO Authors VALUES( '648-92-1872', 'Blotchet-Halls', 'Reginald', '503 745-6402', '55 Hillsdale Bl.', 'Corvallis', 'OR', '97330' );
INSERT INTO Authors VALUES( '341-22-1782', 'Smith', 'Meander', '913 843-0462', '10 Misisipi Dr.', 'Lawrence', 'KS', '66044' );

INSERT INTO Publishers VALUES( '0736', 'New Age Books', '1 1st St','Boston', 'MA' );
INSERT INTO Publishers VALUES( '0877', 'Binnet and Hardley','2 2nd Ave.', 'Washington', 'DC' );
INSERT INTO Publishers VALUES( '1389', 'Algodata Infosystems', '3 3rd Dr.','Berkeley', 'CA' );

INSERT INTO Roysched VALUES( 'BU1032', 0, 5000, 0.10 );
INSERT INTO Roysched VALUES( 'BU1032', 5001, 50000, 0.12 );
INSERT INTO Roysched VALUES( 'PC1035', 0, 2000, 0.10 );
INSERT INTO Roysched VALUES( 'PC1035', 2001, 4000, 0.12 );
INSERT INTO Roysched VALUES( 'PC1035', 4001, 50000, 0.16 );
INSERT INTO Roysched VALUES( 'BU2075', 0, 1000, 0.10 );
INSERT INTO Roysched VALUES( 'BU2075', 1001, 5000, 0.12 );
INSERT INTO Roysched VALUES( 'BU2075', 5001, 7000, 0.16 );
INSERT INTO Roysched VALUES( 'BU2075', 7001, 50000, 0.18 );
INSERT INTO Roysched VALUES( 'PS9999', 0, 50000, 0.10 );
INSERT INTO Roysched VALUES( 'PS2091', 0, 1000, 0.10 );
INSERT INTO Roysched VALUES( 'PS2091', 1001, 5000, 0.12 );
INSERT INTO Roysched VALUES( 'PS2091', 5001, 50000, 0.14 );
INSERT INTO Roysched VALUES( 'PS2106', 0, 2000, 0.10 );
INSERT INTO Roysched VALUES( 'PS2106', 2001, 5000, 0.12 );
INSERT INTO Roysched VALUES( 'PS2106', 5001, 50000, 0.14 );
INSERT INTO Roysched VALUES( 'MC3021', 0, 1000, 0.10 );
INSERT INTO Roysched VALUES( 'MC3021', 1001, 2000, 0.12 );
INSERT INTO Roysched VALUES( 'MC3021', 2001, 6000, 0.14 );
INSERT INTO Roysched VALUES( 'MC3021', 6001, 8000, 0.18 );
INSERT INTO Roysched VALUES( 'MC3021', 8001, 50000, 0.20 );
INSERT INTO Roysched VALUES( 'TC3218', 0, 2000, 0.10 );
INSERT INTO Roysched VALUES( 'TC3218', 2001, 6000, 0.12 );
INSERT INTO Roysched VALUES( 'TC3218', 6001, 8000, 0.16 );
INSERT INTO Roysched VALUES( 'TC3218', 8001, 50000, 0.16 );
INSERT INTO Roysched VALUES( 'PC8888', 0, 5000, 0.10 );
INSERT INTO Roysched VALUES( 'PC8888', 5001, 50000, 0.12 );
INSERT INTO Roysched VALUES( 'PS7777', 0, 5000, 0.10 );
INSERT INTO Roysched VALUES( 'PS7777', 5001, 50000, 0.12 );
INSERT INTO Roysched VALUES( 'PS3333', 0, 5000, 0.10 );
INSERT INTO Roysched VALUES( 'PS3333', 5001, 50000, 0.12 );
INSERT INTO Roysched VALUES( 'MC3026', 0, 1000, 0.10 );
INSERT INTO Roysched VALUES( 'MC3026',1001, 2000, 0.12 );
INSERT INTO Roysched VALUES( 'MC3026', 2001, 6000, 0.14 );
INSERT INTO Roysched VALUES( 'MC3026', 6001, 8000, 0.18 );
INSERT INTO Roysched VALUES( 'MC3026', 8001, 50000, 0.20 );
INSERT INTO Roysched VALUES( 'BU1111', 0, 4000, 0.10 );
INSERT INTO Roysched VALUES( 'BU1111', 4001, 8000, 0.12 );
INSERT INTO Roysched VALUES( 'BU1111', 8001, 50000, 0.14 );
INSERT INTO Roysched VALUES( 'MC2222', 0, 2000, 0.10 );
INSERT INTO Roysched VALUES( 'MC2222', 2001, 4000, 0.12 );
INSERT INTO Roysched VALUES( 'MC2222', 4001, 8000, 0.14 );
INSERT INTO Roysched VALUES( 'MC2222', 8001, 12000, 0.16 );
INSERT INTO Roysched VALUES( 'TC7777', 0, 5000, 0.10 );
INSERT INTO Roysched VALUES( 'TC7777', 5001, 15000, 0.12 );
INSERT INTO Roysched VALUES( 'TC4203', 0, 2000, 0.10 );
INSERT INTO Roysched VALUES( 'TC4203', 2001, 8000, 0.12 );
INSERT INTO Roysched VALUES( 'TC4203', 8001, 16000, 0.14 );
INSERT INTO Roysched VALUES( 'BU7832', 0, 5000, 0.10 );
INSERT INTO Roysched VALUES( 'BU7832', 5001, 50000, 0.12 );
INSERT INTO Roysched VALUES( 'PS1372', 0, 50000, 0.10 );

INSERT INTO TitleAuthors VALUES( '409-56-7008', 'BU1032', 1, 0.60 );
INSERT INTO TitleAuthors VALUES( '486-29-1786', 'PS7777', 1, 1.00 );
INSERT INTO TitleAuthors VALUES( '486-29-1786', 'PC9999', 1, 1.00 );
INSERT INTO TitleAuthors VALUES( '712-45-1867', 'MC2222', 1, 1.00 );
INSERT INTO TitleAuthors VALUES( '172-32-1176', 'PS3333', 1, 1.00 );
INSERT INTO TitleAuthors VALUES( '213-46-8915', 'BU1032', 2, 0.40 );
INSERT INTO TitleAuthors VALUES( '238-95-7766', 'PC1035', 1, 1.00 );
INSERT INTO TitleAuthors VALUES( '213-46-8915', 'BU2075', 1, 1.00 );
INSERT INTO TitleAuthors VALUES( '998-72-3567', 'PS2091', 1, 0.50 );
INSERT INTO TitleAuthors VALUES( '899-46-2035', 'PS2091', 2, 0.50 );
INSERT INTO TitleAuthors VALUES( '998-72-3567', 'PS2106', 1, 1.00 );
INSERT INTO TitleAuthors VALUES( '722-51-5454', 'MC3021', 1, 0.75 );
INSERT INTO TitleAuthors VALUES( '899-46-2035', 'MC3021', 2, 0.25 );
INSERT INTO TitleAuthors VALUES( '807-91-6654', 'TC3218', 1, 1.00 );
INSERT INTO TitleAuthors VALUES( '274-80-9391', 'BU7832', 1, 1.00 );
INSERT INTO TitleAuthors VALUES( '427-17-2319', 'PC8888', 1, 0.50 );
INSERT INTO TitleAuthors VALUES( '846-92-7186', 'PC8888', 2, 0.50 );
INSERT INTO TitleAuthors VALUES( '756-30-7391', 'PS1372', 1, 0.75 );
INSERT INTO TitleAuthors VALUES( '724-80-9391', 'PS1372', 2, 0.25 );
INSERT INTO TitleAuthors VALUES( '724-80-9391', 'BU1111', 1, 0.60 );
INSERT INTO TitleAuthors VALUES( '267-41-2394', 'BU1111', 2, 0.40 );
INSERT INTO TitleAuthors VALUES( '672-71-3249', 'TC7777', 1, 0.40 );
INSERT INTO TitleAuthors VALUES( '267-41-2394', 'TC7777', 2, 0.30 );
INSERT INTO TitleAuthors VALUES( '472-27-2349', 'TC7777', 3, 0.30 );
INSERT INTO TitleAuthors VALUES( '648-92-1872', 'TC4203', 1, 1.00 );

INSERT INTO Titles
VALUES ( 'PC8888', 'Secrets of Silicon Valley', 'popular_comp', '1389', 20.00, 8000.00, 4095,1,
'Muckraking reporting on the world''s largest computer hardware and software manufacturers.',
TO_DATE(  '12/06/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Titles
VALUES ( 'BU1032', 'The Busy Executive''s Database Guide', 'business', '1389', 19.99, 5000.00, 4095, 1,
'An overview of available database systems with emphasis on common business applications.  Illustrated.',
TO_DATE(  '12/06/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Titles
VALUES ( 'PS7777', 'Emotional Security: A New Algorithm', 'psychology', '0736', 7.99, 4000.00, 3336, 1,
'Protecting yourself and your loved ones from undue emotional stress in the modern world.  Use of computer and nutritional aids emphasized.',
TO_DATE(  '12/06/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Titles
VALUES ( 'PS3333', 'Prolonged Data Deprivation: Four Case Studies', 'psychology', '0736', 19.99, 2000.00, 4072,1,
'What happens when the data runs dry?  Searching evaluations of information-shortage effects.',
TO_DATE(  '12/06/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Titles
VALUES ( 'BU1111', 'Cooking with Computers: Surreptitious Balance Sheets', 'business', '1389', 11.95, 5000.00, 3876, 1,
'Helpful hints on how to use your electronic resources to the best advantage.', 
TO_DATE(  '09/06/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Titles
VALUES ( 'MC2222', 'Silicon Valley Gastronomic Treats', 'mod_cook', '0877', 19.99, 0.00, 2032, 1,
 'Favorite recipes for quick, easy, and elegant meals tried and tested by people who never have time to eat, let alone cook.',
TO_DATE(  '09/06/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Titles
VALUES ( 'TC7777', 'Sushi, Anyone?', 'trad_cook', '0877', 14.99, 8000.00, 4095, 1,
'Detailed instructions on improving your position in life by learning how to make authentic Japanese sushi in your spare time. 5-10% increase in number of friends per recipe reported from beta test. ',
TO_DATE(  '12/06/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Titles
VALUES ( 'TC4203', 'Fifty Years in Buckingham Palace Kitchens', 'trad_cook', '0877', 11.95, 4000.00, 15096, 1,
'More anecdotes from the Queen''s favorite cook describing life among English royalty.  Recipes, techniques, tender vignettes.',
TO_DATE(  '12/06/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Titles
VALUES ( 'PC1035', 'But Is It User Friendly?', 'popular_comp', '1389', 22.95, 7000.00, 8780, 1,
'A survey of software for the naive user, focusing on the ''friendliness'' of each.',
TO_DATE(  '30/06/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Titles
VALUES( 'BU2075', 'You Can Combat Computer Stress!', 'business', '0736', 2.99, 10125.00, 18722, 1,
'The latest medical and psychological techniques for living with the electronic office.  Easy-to-understand explanations.',
TO_DATE(  '30/06/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Titles
VALUES( 'PS2091', 'Is Anger the Enemy?', 'psychology', '0736', 10.95, 2275.00, 2045, 1,
'Carefully researched study of the effects of strong emotions on the body. Metabolic CHARts included.',
TO_DATE(  '15/06/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Titles
VALUES( 'PS2106', 'Life Without Fear', 'psychology', '0736', 7.00, 6000.00, 111, 1,
'New exercise, meditation, and nutritional techniques that can reduce the shock of daily interactions. Popular audience.  Sample menus included,exercise video available separately.',
TO_DATE(  '05/10/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Titles
VALUES( 'MC3021', 'The Gourmet Microwave', 'mod_cook', '0877', 2.99, 15000.00,22246, 1,
'Traditional French gourmet recipes adapted for modern microwave cooking.',
TO_DATE(  '18/06/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Titles
VALUES( 'TC3218', 'Onions, Leeks, and Garlic: Cooking Secrets of the Mediterranean',
'trad_cook', '0877', 20.95, 7000.00, 375, 1,
'Profusely illustrated in color, this makes a wonderful gift book for a cuisine-oriented friend.',
TO_DATE(  '21/10/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Titles ( title_id, title, pub_id, contract )
VALUES( 'MC3026', 'The Psychology of Computer Cooking', '0877', 0 );
INSERT INTO Titles
VALUES ( 'BU7832', 'Straight Talk About Computers', 'business', '1389', 19.99, 5000.00, 4095, 1,
'Annotated analysis of what computers can do for you: a no-hype guide for the critical user.',
TO_DATE(  '22/06/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Titles
VALUES( 'PS1372', 'Computer Phobic and Non-Phobic Individuals: Behavior Variations',
'psychology', '0736', 21.59, 7000.00, 375, 1,
'A must for the specialist, this book examines the difference between those who hate and fear computers and those who think they are swell.',
TO_DATE(  '21/10/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Titles ( title_id, title, ttype, pub_id, contract, notes )
VALUES( 'PC9999', 'Net Etiquette', 'popular_comp', '1389', 0, 
'A must-read for computer conferencing debutantes!.' );

INSERT INTO Editors
VALUES ( '321-55-8906', 'DeLongue', 'Martinella', 'project', '415 843-2222', '3000 6th St.', 'Berkeley', 'CA', '94710' );
INSERT INTO Editors
VALUES ( '723-48-9010', 'Sparks', 'Manfred', 'copy', '303 721-3388', '15 Sail', 'Denver', 'CO', '80237' );
INSERT INTO Editors
VALUES ( '777-02-9831', 'Samuelson', 'Bernard', 'project', '415 843-6990', '27 Yosemite', 'Oakland', 'CA', '94609' );
INSERT INTO Editors
VALUES ( '777-66-9902', 'Almond', 'Alfred', 'copy', '312 699-4177', '1010 E. Devon', 'Chicago', 'IL', '60018' );
INSERT INTO Editors
VALUES ( '826-11-9034', 'Himmel', 'Eleanore', 'project', '617 423-0552', '97 Bleaker', 'Boston', 'MA', '02210' );
INSERT INTO Editors
VALUES ( '885-23-9140', 'Rutherford-Hayes', 'Hannah', 'project','301 468-3909', '32 Rockbill Pike', 'Rockbill', 'MD', '20852' );
INSERT INTO Editors
VALUES ( '993-86-0420', 'McCann', 'Dennis', 'acquisition', '301 468-3909', '32 Rockbill Pike', 'Rockbill', 'MD', '20852' );
INSERT INTO Editors
VALUES ( '943-88-7920', 'Kaspchek', 'Christof', 'acquisition', '415 549-3909', '18 Severe Rd.', 'Berkeley', 'CA', '94710' );
INSERT INTO Editors
VALUES ( '234-88-9720', 'Hunter', 'Amanda', 'acquisition', '617 432-5586', '18 Dowdy Ln.', 'Boston', 'MA', '02210' );

INSERT INTO TitlEditors VALUES ( '826-11-9034', 'BU2075', 2 );
INSERT INTO TitlEditors VALUES ( '826-11-9034', 'PS2091', 2 );
INSERT INTO TitlEditors VALUES ( '826-11-9034', 'PS2106', 2 );
INSERT INTO TitlEditors VALUES ( '826-11-9034', 'PS3333', 2 );
INSERT INTO TitlEditors VALUES ( '826-11-9034', 'PS7777', 2 );
INSERT INTO TitlEditors VALUES ( '826-11-9034', 'PS1372', 2 );
INSERT INTO TitlEditors VALUES ( '885-23-9140', 'MC2222', 2 );
INSERT INTO TitlEditors VALUES ( '885-23-9140', 'MC3021', 2 );
INSERT INTO TitlEditors VALUES ( '885-23-9140', 'TC3281', 2 );
INSERT INTO TitlEditors VALUES ( '885-23-9140', 'TC4203', 2 );
INSERT INTO TitlEditors VALUES ( '885-23-9140', 'TC7777', 2 );
INSERT INTO TitlEditors VALUES ( '321-55-8906', 'BU1032', 2 );
INSERT INTO TitlEditors VALUES ( '321-55-8906', 'BU1111', 2 );
INSERT INTO TitlEditors VALUES ( '321-55-8906', 'BU7832', 2 );
INSERT INTO TitlEditors VALUES ( '321-55-8906', 'PC1035', 2 );
INSERT INTO TitlEditors VALUES ( '321-55-8906', 'PC8888', 2 );
INSERT INTO TitlEditors VALUES ( '321-55-8906', 'BU2075', 3 );
INSERT INTO TitlEditors VALUES ( '777-02-9831', 'PC1035', 3 );
INSERT INTO TitlEditors VALUES ( '777-02-9831', 'PC8888', 3 );
INSERT INTO TitlEditors VALUES ( '943-88-7920', 'BU1032', 1 );
INSERT INTO TitlEditors VALUES ( '943-88-7920', 'BU1111', 1 );
INSERT INTO TitlEditors VALUES ( '943-88-7920', 'BU2075', 1 );
INSERT INTO TitlEditors VALUES ( '943-88-7920', 'BU7832', 1 );
INSERT INTO TitlEditors VALUES ( '943-88-7920', 'PC1035', 1 );
INSERT INTO TitlEditors VALUES ( '943-88-7920', 'PC8888', 1 );
INSERT INTO TitlEditors VALUES ( '993-86-0420', 'PS1372', 1 );
INSERT INTO TitlEditors VALUES ( '993-86-0420', 'PS2091', 1 );
INSERT INTO TitlEditors VALUES ( '993-86-0420', 'PS2106', 1 );
INSERT INTO TitlEditors VALUES ( '993-86-0420', 'PS3333', 1 );
INSERT INTO TitlEditors VALUES ( '993-86-0420', 'PS7777', 1 );
INSERT INTO TitlEditors VALUES ( '993-86-0420', 'MC2222', 1 );
INSERT INTO TitlEditors VALUES ( '993-86-0420', 'MC3021', 1 );
INSERT INTO TitlEditors VALUES ( '993-86-0420', 'TC3218', 1 );
INSERT INTO TitlEditors VALUES ( '993-86-0420', 'TC4203', 1 );
INSERT INTO TitlEditors VALUES ( '993-86-0420', 'TC7777', 1 );

INSERT INTO Sales VALUES( 1,'7066', 'QA7442.3', TO_DATE(  '13/09/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Sales VALUES( 2,'7067', 'D4482', TO_DATE(  '14/09/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Sales VALUES( 3,'7131', 'N914008', TO_DATE(  '14/09/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Sales VALUES( 4,'7131', 'N914014', TO_DATE(  '14/09/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Sales VALUES( 5,'8042', '423LL922', TO_DATE(  '14/09/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Sales VALUES( 6,'8042', '423LL930', TO_DATE(  '14/09/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Sales VALUES( 7, '6380', '722a', TO_DATE(  '13/09/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Sales VALUES( 8,'6380', '6871', TO_DATE(  '14/09/1995', 'DD/MM/YYYY'  )  );
INSERT INTO Sales VALUES( 9,'8042','P723', TO_DATE(  '11/03/1998', 'DD/MM/YYYY'  )  );
INSERT INTO Sales VALUES( 19,'7896','X999', TO_DATE(  '21/02/1998', 'DD/MM/YYYY'  )  );
INSERT INTO Sales VALUES( 10,'7896','QQ2299', TO_DATE(  '28/10/1997', 'DD/MM/YYYY'  )  );
INSERT INTO Sales VALUES( 11,'7896','TQ456', TO_DATE(  '12/12/1997', 'DD/MM/YYYY'  )  );
INSERT INTO Sales VALUES( 12,'8042','QA879.1', TO_DATE(  '22/05/1997', 'DD/MM/YYYY'  )  );
INSERT INTO Sales VALUES( 13,'7066','A2976', TO_DATE(  '24/05/1997', 'DD/MM/YYYY'  )  );
INSERT INTO Sales VALUES( 14,'7131','P3087a', TO_DATE(  '29/05/1997', 'DD/MM/YYYY'  )  );
INSERT INTO Sales VALUES( 15,'7067','P2121', TO_DATE(  '15/06/1997', 'DD/MM/YYYY'  )  );

INSERT INTO SalesDetails VALUES( 1, 75, 75,'PS2091', TO_DATE(  '15/09/1995', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 2, 10, 10,'PS2091', TO_DATE(  '15/09/1995', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 3, 20, 720,'PS2091', TO_DATE(  '18/09/1995', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 4, 25, 20,'MC3021', TO_DATE(  '18/09/1995', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 5, 15, 15,'MC3021', TO_DATE(  '14/09/1995', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 6, 10, 3,'BU1032', TO_DATE(  '22/09/1995', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 7, 3, 3,'PS2091', TO_DATE(  '20/09/1995', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 8, 5, 5,'BU1032', TO_DATE(  '14/09/1995', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 9, 25, 5,'BU1111', TO_DATE(  '28/03/1998', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 19, 35, 35,'BU2075', TO_DATE(  '15/03/1998', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 10, 15, 15,'BU7832', TO_DATE(  '29/10/1997', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 11, 10, 10,'MC2222', TO_DATE(  '12/01/1998', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 12, 30, 30,'PC1035', TO_DATE(  '24/05/1997', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 13, 50, 50,'PC8888', TO_DATE(  '24/05/1997', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 14, 20, 20,'PS1372', TO_DATE(  '29/05/1997', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 14, 25, 25,'PS2106', TO_DATE(  '29/04/1997', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 14, 15, 10,'PS3333', TO_DATE(  '29/05/1997', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 14, 25, 25,'PS7777', TO_DATE(  '13/06/1997', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 15, 40, 40,'TC3218', TO_DATE(  '15/06/1997', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 15, 20, 20,'TC4203', TO_DATE(  '30/05/1997', 'DD/MM/YYYY'  )  );
INSERT INTO SalesDetails VALUES( 15, 20, 10,'TC7777', TO_DATE(  '17/06/1997', 'DD/MM/YYYY'  )  );

DROP VIEW TitleView;
CREATE VIEW TitleView
AS
SELECT title, au_ord, au_lname, price, ytd_sales, pub_id
FROM Authors, Titles, TitleAuthors
WHERE Authors.au_id = TitleAuthors.au_id
      AND Titles.title_id = TitleAuthors.title_id;

DROP VIEW Oaklanders;
CREATE VIEW Oaklanders
AS
SELECT au_fname, au_lname, title
FROM Authors, Titles, TitleAuthors
WHERE Authors.au_id = TitleAuthors.au_id
      AND Titles.title_id = TitleAuthors.title_id
      AND city = 'Oakland';

CREATE OR REPLACE VIEW Books
AS
SELECT Titles.title_id, au_ord, au_lname, au_fname
FROM Authors, Titles, TitleAuthors
WHERE Authors.au_id=TitleAuthors.au_id
      AND Titles.title_id = TitleAuthors.title_id;

CREATE OR REPLACE VIEW RoyaltyChecks
AS
SELECT au_lname, au_fname, SUM( price*ytd_sales*royalty*royaltyshare ) AS Total_Income
FROM Authors, Titles, TitleAuthors, Roysched
WHERE Authors.au_id=TitleAuthors.au_id
      AND Titles.title_id = TitleAuthors.title_id
      AND Titles.title_id = Roysched.title_id
      AND ytd_sales BETWEEN lorange AND hirange
GROUP BY au_lname, au_fname;

CREATE OR REPLACE VIEW CurrentInfo ( PUB#, TTYPE, INCOME, AVG_PRICE, AVG_SALES )
AS
SELECT pub_id, ttype, SUM( price * ytd_sales ), AVG( price ), AVG( ytd_sales )
FROM Titles
GROUP BY pub_id, ttype;

CREATE OR REPLACE VIEW HiPrice
AS
SELECT *
FROM Titles
WHERE price > 15
  AND advance > 5000;

CREATE OR REPLACE VIEW Cities ( Author, Authorcity, Pub, Pubcity )
AS
SELECT au_lname, Authors.city, pub_name, Publishers.city
FROM Authors, Publishers
WHERE Authors.city = Publishers.city;

CREATE OR REPLACE VIEW HighAverage
AS
SELECT Authors.au_id, Titles.title_id, pub_name, price
FROM Authors, TitleAuthors, Titles, Publishers
WHERE Authors.au_id = TitleAuthors.au_id 
      AND Titles.title_id = TitleAuthors.title_id 
      AND Titles.pub_id = Publishers.pub_id 
      AND price > ( SELECT AVG( price ) FROM Titles );

CREATE OR REPLACE VIEW HighBandH
AS 
SELECT *
FROM HighAverage
WHERE pub_name = 'Binnet and Hardley';

CREATE OR REPLACE VIEW Number1
AS 
SELECT au_lname, phone
FROM Authors
WHERE zip LIKE '94%';

CREATE OR REPLACE VIEW Number2
AS 
SELECT au_lname, phone
FROM Number1
WHERE au_lname LIKE '[M-Z]%';

CREATE OR REPLACE VIEW Number3
AS 
SELECT au_lname, phone
FROM Number2
WHERE au_lname = 'MacFeather';

CREATE OR REPLACE VIEW Categories ( Category, Average_Price )
AS 
SELECT ttype, AVG( price )
FROM Titles
GROUP BY ttype;

CREATE OR REPLACE VIEW Accounts ( title, advance, gross_sales )
AS
SELECT title_id, advance, price * ytd_sales
FROM Titles
WHERE price > 15
      AND advance > 5000;

/*
***************************
** End of bookbiz script **
***************************
*/
